@@ -17,14 +17,15 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
 
 class plugin(Plugin):
     summary =_('''
-    SELinux is preventing $SOURCE from making the program stack executable.
+    SELinux is preventing $SOURCE_PATH from making the program stack executable.
     ''')
     
     problem_description = _('''
@@ -38,9 +39,8 @@ class plugin(Plugin):
     <a href="http://people.redhat.com/drepper/selinux-mem.html">SELinux Memory Protection Tests</a>
     web page explains how to remove this requirement.  If $SOURCE does not
     work and you need it to work, you can configure SELinux
-    temporarily to allow this access until the application is fixed. Please file a <a
-    href="http://bugzilla.redhat.com/bugzilla/enter_bug.cgi">bug
-    report</a> against this package.
+    temporarily to allow this access until the application is fixed. Please 
+file a bug report.
     ''')
     
     fix_description = _('''
@@ -52,7 +52,7 @@ class plugin(Plugin):
     run correctly, you can change the context of the executable to
     execmem_exec_t. "chcon -t execmem_exec_t
     '$SOURCE_PATH'"
-    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t execmem_exec_t '$SOURCE_PATH'"
+    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t execmem_exec_t '$FIX_SOURCE_PATH'"
     
     ''')
 
