@@ -17,7 +17,8 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
@@ -31,7 +32,7 @@ class plugin(Plugin):
     problem_description = _('''
     SELinux policy is preventing the ftp daemon from writing to a public
     directory.  If ftpd is not setup to allow anonymous writes, this
-    could signal a intrusion attempt.
+    could signal an intrusion attempt.
     ''')
 
     fix_description = _('''
@@ -56,7 +57,9 @@ class plugin(Plugin):
             avc.set_template_substitutions(BOOLEAN="allow_ftpd_anon_write")
             return self.report(avc, _("FTP"),
                                self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+                               self.fix_description, self.fix_cmd,
+                               level="green")
+
         return None
 
 
