@@ -17,27 +17,29 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
 
 class plugin(Plugin):
     summary =_('''
-    SELinux is preventing the $SOURCE ($SOURCE_TYPE) from connecting to port $PORT_NUMBER.
+    SELinux is preventing $SOURCE_PATH from connecting to port $PORT_NUMBER.
     ''')
 
     problem_description = _('''
-    SELinux has denied the $SOURCE from connecting to a network port $PORT_NUMBER which does not have an SELinux type associated with it.
-    If $SOURCE is supposed to be allowed to connect on this port, you can use the semanage command to add this port to a port type that $SOURCE_TYPE can connect to.   <i>semanage port -l</i> will list all port types. Please file a <a href="http://bugzilla.redhat.com/bugzilla/enter_bug.cgi">bug report</a> against the selinux-policy package.
-If $SOURCE is not supposed
-    to connect to this port, this could signal a intrusion attempt.   
+    SELinux has denied $SOURCE from connecting to a network port $PORT_NUMBER which does not have an SELinux type associated with it.
+    If $SOURCE should be allowed to connect on $PORT_NUMBER, use the <i>semanage</i> command to assign $PORT_NUMBER to a port type that $SOURCE_TYPE can connect to (%s). 
+    <br><br>If $SOURCE is not supposed
+    to connect to $PORT_NUMBER, this could signal a intrusion attempt.
     ''')
+    
 
     fix_description = _('''
-    If you want to allow $SOURCE to connect to this port
-    semanage port -a -t PORT_TYPE -p PROTOCOL $PORT_NUMBER
-    Where PORT_TYPE is a type that $SOURCE_TYPE can connect.
+    If you want to allow $SOURCE to connect to $PORT_NUMBER, you can execute <br>
+    <b>semanage port -a -t PORT_TYPE -p %s $PORT_NUMBER</b>
+    <br>where PORT_TYPE is one of the following: %s.
     ''')
 
     fix_cmd = ''
@@ -50,9 +52,12 @@ If $SOURCE is not supposed
         if avc.matches_target_types(['reserved_port_t', 'port_t']) and \
            avc.has_any_access_in(['name_connect']):
             # MATCH
+            target_types = ", ".join(avc.allowed_target_types())
+            problem_description = self.problem_description % target_types
+            fix_description = self.fix_description % (avc.tclass.split("_")[0], target_types)
             return self.report(avc, _("Network Ports"),
-                               self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+                               self.summary, problem_description,
+                               fix_description, self.fix_cmd)
 
         return None
 
