@@ -17,26 +17,27 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
 
 class plugin(Plugin):
     summary =_('''
-    SELinux is preventing cvs ($SOURCE) "$ACCESS" to $TARGET_PATH ($TARGET_TYPE).
+    SELinux is preventing cvs ($SOURCE_PATH) "$ACCESS" access to $TARGET_PATH
     ''')
 
     problem_description = _('''
     SELinux denied cvs access to $TARGET_PATH.
-    If this is a CVS repository it has to have a file context label of
-    cvs_data_t. If you did not intend to use $TARGET_PATH as a cvs repository
-    it could indicate either a bug or it could signal a intrusion attempt.
+    If this is a CVS repository it needs to have a file context label of
+    cvs_data_t. If you did not intend to use $TARGET_PATH as a CVS repository
+    it could indicate either a bug or it could signal an intrusion attempt.
     ''')
 
     fix_description = _('''
     You can alter the file context by executing chcon -R -t cvs_data_t '$TARGET_PATH'
-    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t cvs_data_t '$TARGET_PATH'"
+    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t cvs_data_t '$FIX_TARGET_PATH'"
     
     ''')
 
@@ -53,7 +54,8 @@ class plugin(Plugin):
             # MATCH
             return self.report(avc, _("File Label"),
                                self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+                               self.fix_description, self.fix_cmd,
+                               level="green")
         else:
             return None
 
