@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2006 Red Hat, Inc.
+# Copyright (C) 2006,2009 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,14 +17,15 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
 
 class plugin(Plugin):
     summary =_('''
-    SELinux is preventing $SOURCE ($SOURCE_TYPE) "$ACCESS" on $TARGET_PATH ($TARGET_TYPE).
+    SELinux is preventing $SOURCE_PATH "$ACCESS" access to $TARGET_PATH.
     ''')
 
     problem_description = _('''
@@ -42,9 +43,9 @@ class plugin(Plugin):
     fix_description = _('''
     You can alter the file context by executing "chcon -t bin_t '$TARGET_PATH'" or
     "chcon -t lib_t '$TARGET_PATH'" if it is a shared library.  If you want to make these changes permanent you must execute the semanage command.
-    "semanage fcontext -a -t bin_t '$TARGET_PATH'" or
-    "semanage fcontext -a -t lib_t '$TARGET_PATH'".
-    If you feel this executable/shared library is in the wrong location please file a bug against the package that includes the file.  If you feel that SELinux should know about this file and label it correctly please file a bug against     <a href="http://bugzilla.redhat.com/bugzilla/enter_bug.cgi">SELinux policy</a>.
+    "semanage fcontext -a -t bin_t '$FIX_TARGET_PATH'" or
+    "semanage fcontext -a -t lib_t '$FIX_TARGET_PATH'".
+    If you feel this executable/shared library is in the wrong location please file a bug against the package that includes the file.  If you feel that SELinux should know about this file and label it correctly please file a bug against SELinux policy.
 
     ''')
 
