@@ -17,27 +17,28 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
 
 class plugin(Plugin):
     summary =_('''
-    SELinux is preventing $SOURCE ($SOURCE_TYPE) "$ACCESS" to $TARGET_PATH ($TARGET_TYPE).
+    SELinux is preventing $SOURCE_PATH "$ACCESS" access to $TARGET_PATH.
     ''')
 
     problem_description = _('''
     SELinux denied access to $TARGET_PATH requested by $SOURCE.
-    $TARGET_PATH has a context used for sharing by different program. If you
+    $TARGET_PATH has a context used for sharing by a different program. If you
     would like to share $TARGET_PATH from $SOURCE also, you need to
     change its file context to public_content_t.  If you did not intend to
-    this access, this could signal a intrusion attempt.
+    allow this access, this could signal an intrusion attempt.
     ''')
 
     fix_description = _('''
     You can alter the file context by executing chcon -t public_content_t '$TARGET_PATH'
-    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t public_content_t '$TARGET_PATH'"
+    You must also change the default file context files on the system in order to preserve them even on a full relabel.  "semanage fcontext -a -t public_content_t '$FIX_TARGET_PATH'"
     ''')
 
     fix_cmd = "chcon -t public_content_t '$TARGET_PATH'"
