@@ -1,7 +1,7 @@
 #
 # Authors: Dan Walsh <dwalsh@redhat.com>
 #
-# Copyright (C) 2007, 2008 Red Hat, Inc.
+# Copyright (C) 2007, 2008, 2009 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,8 @@
 #
 
 import gettext
-_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext
+translation=gettext.translation('setroubleshoot-plugins', fallback=True)
+_=translation.ugettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
@@ -29,7 +30,7 @@ from stat import *
 import selinux
 class plugin(Plugin):
     summary = _('''
-    SELinux is preventing $SOURCE ($SOURCE_TYPE) "$ACCESS" to $TARGET_PATH ($TARGET_TYPE).
+    SELinux is preventing $SOURCE_PATH "$ACCESS" access to $TARGET_PATH.
     ''')
 
     problem_description = _('''
@@ -44,7 +45,7 @@ class plugin(Plugin):
         <li>The SELinux policy might override the default label inherited from the parent directory by
             specifying a process running in context A which creates a file in a directory labeled B
             will instead create the file with label C. An example of this would be the dhcp client running
-            with the dhclient_t type and creates a file in the directory /etc. This file would normally
+            with the dhclient_t type and creating a file in the directory /etc. This file would normally
             receive the etc_t type due to parental inheritance but instead the file
             is labeled with the net_conf_t type because the SELinux policy specifies this.
         <li>Users can change the file context on a file using tools such as chcon, or restorecon.
@@ -55,9 +56,7 @@ class plugin(Plugin):
     However, this might also indicate a bug in SELinux because the file should not have been labeled
     with this type.
     <p>
-    If you believe this is a bug, please file a
-    <a href="http://bugzilla.redhat.com/bugzilla/enter_bug.cgi">bug report</a>
-    against this package.
+    If you believe this is a bug, please file a bug report against this package.
     ''')
 
     fix_description = _('''
@@ -66,11 +65,12 @@ class plugin(Plugin):
     you can recursively restore using restorecon -R '$TARGET_PATH'.
     ''')
 
-    fix_cmd = "restorecon '$TARGET_PATH'"
+    fix_cmd = "/sbin/restorecon '$TARGET_PATH'"
 
+    
     def __init__(self):
         Plugin.__init__(self, __name__)
-        self.set_priority(53)
+        self.set_priority(52)
 
     def analyze(self, avc):
         if not avc.query_environment: return None
@@ -90,7 +90,7 @@ class plugin(Plugin):
                     avc.set_template_substitutions(MATCHTYPE=mcon_type)
                     return self.report(avc, _("File Label"),
                                        self.summary, self.problem_description,
-                                       self.fix_description, self.fix_cmd)
+                                       self.fix_description, self.fix_cmd, level="yellow", fixable=True, button_text=_("Restore Context"))
         except:
             pass
 
